@@ -58,6 +58,12 @@ public:
 		m_filterExpression = filterExpression;
 	}
 
+	/**
+	 * Check if filter expression is empty.
+	 * @return true if filter expression is empty.
+	 */
+	bool isEmptyFilterExpression() const { return m_filterExpression.isEmpty(); }
+
 	/**
 	 * Initialize the parser.
 	 * This method has to be called before the first call to parse()
