@@ -270,14 +270,15 @@ QString CommandFormatReplacer::getToolTip(bool onlyRows)
 /**
  * Constructor.
  * @param parent parent widget
+ * @param app    application widget
  */
-FileList::FileList(QWidget* parent) :
+FileList::FileList(QWidget* parent, Kid3App* app) :
 #if QT_VERSION >= 0x040000
 	QTreeWidget(parent), m_iterator(0),
 #else
 	QListView(parent),
 #endif
-	m_currentItemInDir(0), m_process(0)
+	m_currentItemInDir(0), m_process(0), m_app(app)
 {
 #if QT_VERSION >= 0x040000
 	setSelectionMode(ExtendedSelection);
@@ -822,6 +823,67 @@ bool FileList::readDir(const QString& name, const QString& fileName)
 	return false;
 }
 
+/**
+ * Fill the filelist with the files from a DirContents tree.
+ *
+ * @param dirContents recursive information about directory and files
+ * @param item        parent directory item or 0 if top-level
+ * @param listView    parent list view if top-level, else 0
+ */
+static void setSubDirectoryFromDirContents(
+	const DirContents& dirContents, FileListItem* item, FileList* listView)
+{
+	const DirInfo* dirInfo =
+		listView ? listView->getDirInfo() : item->getDirInfo();
+	QString dirname = dirContents.getDirname();
+	FileListItem* last = 0;
+	for (DirContents::DirContentsList::const_iterator it =
+				 dirContents.getDirs().begin();
+			 it != dirContents.getDirs().end(); ++it) {
+		if (item) {
+			last = new FileListItem(item, last, 0);
+		} else if (listView) {
+			last = new FileListItem(listView, last, 0);
+		}
+		if (last) {
+			const DirContents& subDirContents = *(*it);
+			last->setDirInfo(
+				new DirInfo(subDirContents.getDirname(), subDirContents.getNumFiles()));
+			setSubDirectoryFromDirContents(subDirContents, last, 0);
+#if QT_VERSION >= 0x040000
+			last->setExpanded(true);
+#else
+			last->setOpen(true);
+#endif
+		}
+	}
+	for (QStringList::const_iterator it = dirContents.getFiles().begin();
+			 it != dirContents.getFiles().end(); ++it) {
+		QString filename = dirname + QDir::separator() + *it;
+		TaggedFile* taggedFile = TaggedFile::createFile(dirInfo, *it);
+		if (taggedFile) {
+			if (item) {
+				last = new FileListItem(item, last, taggedFile);
+			} else if (listView) {
+				last = new FileListItem(listView, last, taggedFile);
+			}
+		}
+	}
+}
+
+/**
+ * Fill the filelist with the files from a DirContents tree.
+ *
+ * @param dirContents recursive information about directory and files
+ */
+void FileList::setFromDirContents(const DirContents& dirContents)
+{
+	clear();
+	m_dirInfo.setDirname(dirContents.getDirname());
+	m_dirInfo.setNumFiles(dirContents.getNumFiles());
+	setSubDirectoryFromDirContents(dirContents, 0, this);
+}
+
 /**
  * Refresh text of all files in listview and check if any file is modified.
  *
@@ -863,8 +925,13 @@ void FileList::contextMenu(
 	if (item && !Kid3App::s_miscCfg.m_contextMenuCommands.empty()) {
 #if QT_VERSION >= 0x040000
 		QMenu menu(this);
+		menu.addAction(i18n("&Expand all"), this, SLOT(expandAll()));
+		menu.addAction(i18n("&Collapse all"), this, SLOT(collapseAll()));
 		menu.addAction(i18n("&Rename"), this, SLOT(renameFile()));
 		menu.addAction(i18n("&Delete"), this, SLOT(deleteFile()));
+#ifdef HAVE_PHONON
+		menu.addAction(i18n("&Play"), m_app, SLOT(slotPlayAudio()));
+#endif
 		int id = 0;
 		for (MiscConfig::MenuCommandList::const_iterator
 					 it = Kid3App::s_miscCfg.m_contextMenuCommands.begin();
@@ -876,8 +943,13 @@ void FileList::contextMenu(
 		connect(&menu, SIGNAL(triggered(QAction*)), this, SLOT(executeAction(QAction*)));
 #else
 		QPopupMenu menu(this);
+		menu.insertItem(i18n("&Expand all"), this, SLOT(expandAll()));
+		menu.insertItem(i18n("&Collapse all"), this, SLOT(collapseAll()));
 		menu.insertItem(i18n("&Rename"), this, SLOT(renameFile()));
 		menu.insertItem(i18n("&Delete"), this, SLOT(deleteFile()));
+#ifdef HAVE_PHONON
+		menu.insertItem(i18n("&Play"), m_app, SLOT(slotPlayAudio()));
+#endif
 		int id = 0;
 		for (MiscConfig::MenuCommandList::const_iterator
 					 it = Kid3App::s_miscCfg.m_contextMenuCommands.begin();
@@ -1070,6 +1142,40 @@ void FileList::executeAction(QAction* action)
 void FileList::executeAction(QAction*) {}
 #endif
 
+/**
+ * Expand or collapse all folders.
+ *
+ * @param expand true to expand, false to collapse
+ */
+void FileList::setAllExpanded(bool expand)
+{
+	FileListItem* item = firstFileOrDir();
+	while (item != 0) {
+#if QT_VERSION >= 0x040000
+		item->setExpanded(expand);
+#else
+		item->setOpen(expand);
+#endif
+		item = nextFileOrDir();
+	}
+}
+
+/**
+ * Expand all folders.
+ */
+void FileList::expandAll()
+{
+	setAllExpanded(true);
+}
+
+/**
+ * Collapse all folders.
+ */
+void FileList::collapseAll()
+{
+	setAllExpanded(false);
+}
+
 /**
  * Rename the selected file(s).
  */
