@@ -41,6 +41,7 @@ class QAction;
 #endif
 #include "dirinfo.h"
 
+class Kid3App;
 class FileListItem;
 class TaggedFile;
 class ExternalProcess;
@@ -56,8 +57,9 @@ public:
 	/**
 	 * Constructor.
 	 * @param parent parent widget
+	 * @param app    application widget
 	 */
-	FileList(QWidget* parent = 0);
+	FileList(QWidget* parent, Kid3App* app);
 
 	/**
 	 * Destructor.
@@ -164,6 +166,13 @@ public:
 	 */
 	bool readDir(const QString& name, const QString& fileName = QString());
 
+	/**
+	 * Fill the filelist with the files from a DirContents tree.
+	 *
+	 * @param dirContents recursive information about directory and files
+	 */
+	void setFromDirContents(const DirContents& dirContents);
+
 	/**
 	 * Refresh text of all files in listview and check if any file is modified.
 	 *
@@ -178,6 +187,28 @@ public:
 	 */
 	const DirInfo* getDirInfo() const { return &m_dirInfo; }
 
+#if QT_VERSION >= 0x040000
+	/**
+	 * Get the stored current selection.
+	 * @return stored selection.
+	 */
+	const QList<QTreeWidgetItem*>& getCurrentSelection() const {
+		return m_currentSelection;
+	}
+
+	/**
+	 * Clear the stored current selection.
+	 */
+	void clearCurrentSelection() { m_currentSelection.clear(); }
+
+	/**
+	 * Update the stored current selection with the list of all selected items.
+	 */
+	void updateCurrentSelection() {
+		m_currentSelection = selectedItems();
+	}
+#endif
+
 	/**
 	 * Fill the filelist with the files found in the directory tree.
 	 *
@@ -233,6 +264,16 @@ private slots:
 	 */
 	void executeAction(QAction* action);
 
+	/**
+	 * Expand all folders.
+	 */
+	void expandAll();
+
+	/**
+	 * Collapse all folders.
+	 */
+	void collapseAll();
+
 	/**
 	 * Rename the selected file(s).
 	 */
@@ -298,6 +339,13 @@ private:
 	 */
 	QStringList formatStringList(const QStringList& format);
 
+	/**
+	 * Expand or collapse all folders.
+	 *
+	 * @param expand true to expand, false to collapse
+	 */
+	void setAllExpanded(bool expand);
+
 	/** information about directory */
 	DirInfo m_dirInfo;
 	/** iterator pointing to current file */
@@ -310,6 +358,10 @@ private:
 	FileListItem* m_currentItemInDir;
 	/** Process for context menu commands */
 	ExternalProcess* m_process;
+#if QT_VERSION >= 0x040000
+	QList<QTreeWidgetItem*> m_currentSelection;
+#endif
+	Kid3App* m_app;
 };
 
 #endif // FILELIST_H
