@@ -47,6 +47,7 @@ typedef KMainWindow Kid3AppBaseClass;
 #include "generalconfig.h" // Kid3Settings
 class QAction;
 class BrowserDialog;
+class RecentFilesMenu;
 /** Base class for main window. */
 typedef QMainWindow Kid3AppBaseClass;
 #endif
@@ -79,6 +80,10 @@ class FileFilter;
 class QImage;
 class DownloadDialog;
 class PlaylistDialog;
+#ifdef HAVE_PHONON
+class PlayToolBar;
+#endif
+class DirContents;
 
 /** Kid3 application */
 class Kid3App : public Kid3AppBaseClass
@@ -229,8 +234,10 @@ public:
 	 * Select a frame type and add such a frame to frame list.
 	 *
 	 * @param frame frame to add, if 0 the user has to select and edit the frame
+	 * @param edit  if frame is set and edit is true, the user can edit the frame
+	 *              before it is added
 	 */
-	void addFrame(const Frame* frame = 0);
+	void addFrame(const Frame* frame = 0, bool edit = false);
 
 	/**
 	 * Set the directory name from the tags.
@@ -250,10 +257,11 @@ public:
 	 * Number tracks in selected files of directory.
 	 *
 	 * @param nr start number
+	 * @param total total number of tracks, used if >0
 	 * @param destV1 true to set numbers in tag 1
 	 * @param destV2 true to set numbers in tag 2
 	 */
-	void numberTracks(int nr, bool destV1, bool destV2);
+	void numberTracks(int nr, int total, bool destV1, bool destV2);
 
 	/**
 	 * Export.
@@ -266,6 +274,11 @@ public:
 	 */
 	bool exportTags(int tagNr, const QString& path, int fmtIdx);
 
+	/**
+	 * Edit a picture frame if one exists or add a new one.
+	 */
+	void editOrAddPicture();
+
 	/**
 	 * Display help for a topic.
 	 *
@@ -282,7 +295,7 @@ public:
 	/**
 	 * Read file with TagLib if it has an ID3v2.4 tag.
 	 *
-	 * @param item       file list item, can be updated
+	 * @param item       file list item, can be updated if not null
 	 * @param taggedFile tagged file
 	 *
 	 * @return tagged file (can be new TagLibFile).
@@ -450,6 +463,13 @@ public slots:
 	 */
 	void slotFileOpenRecentUrl(const KUrl& url);
 
+	/**
+	 * Open recent directory.
+	 *
+	 * @param dir directory to open
+	 */
+	void slotFileOpenRecentDirectory(const QString& dir);
+
 	/**
 	 * Quit application.
 	 */
@@ -566,14 +586,9 @@ public slots:
 	void slotExport();
 
 	/**
-	 * Show or hide ID3v1.1 controls.
+	 * Toggle auto hiding of tags.
 	 */
-	void slotSettingsShowHideV1();
-
-	/**
-	 * Show or hide ID3v2.3 controls.
-	 */
-	void slotSettingsShowHideV2();
+	void slotSettingsAutoHideTags();
 
 	/**
 	 * Show or hide picture.
@@ -620,6 +635,11 @@ public slots:
 	 */
 	void slotConvertToId3v23();
 
+	/**
+	 * Play audio file.
+	 */
+	void slotPlayAudio();
+
 	/**
 	 * Update GUI controls from the tags in the files.
 	 * The new selection is stored and the GUI controls and frame list
@@ -752,22 +772,21 @@ private:
 	bool writePlaylist(const PlaylistConfig& cfg);
 
 	/**
-	 * Show or hide the ID3V1.1 controls according to the settings and
-	 * set the menu entries appropriately.
+	 * Get number of tracks in current directory.
+	 *
+	 * @return number of tracks, 0 if not found.
 	 */
-	void updateHideV1();
+	int getTotalNumberOfTracksInDir();
 
 	/**
-	 * Show or hide the ID3V2.3 controls according to the settings and
-	 * set the menu entries appropriately.
+	 * Apply a file filter to a directory.
+	 *
+	 * @param fileFilter filter to apply
+	 * @param dirContents directory contents, will be filled with results
+	 *
+	 * @return true if ok, false if aborted.
 	 */
-	void updateHideV2();
-
-	/**
-	 * Show or hide the picture according to the settings and
-	 * set the menu entries appropriately.
-	 */
-	void updateHidePicture();
+	bool applyFilterToDir(FileFilter& fileFilter, DirContents* dirContents);
 
 	/**
 	 * Set filter state.
@@ -811,6 +830,10 @@ private:
 	DownloadDialog* m_downloadDialog;
 	/** Playlist dialog */
 	PlaylistDialog* m_playlistDialog;
+#ifdef HAVE_PHONON
+	/** Play toolbar */
+	PlayToolBar* m_playToolBar;
+#endif
 	/** Frame list */
 	FrameList* m_framelist;
 
@@ -821,13 +844,16 @@ private:
 	KRecentFilesAction* m_fileOpenRecent;
 	KToggleAction* m_viewToolBar;
 	KToggleAction* m_viewStatusBar;
-	KAction* m_settingsShowHideV1;
-	KAction* m_settingsShowHideV2;
-	KAction* m_settingsShowHidePicture;
+	KToggleAction* m_settingsAutoHideTags;
+	KToggleAction* m_settingsShowHidePicture;
 #else
 	Kid3Settings* m_config;
-	QAction* m_settingsShowHideV1;
-	QAction* m_settingsShowHideV2;
+	RecentFilesMenu* m_fileOpenRecent;
+#if QT_VERSION >= 0x040000
+	QAction* m_viewToolBar;
+#endif
+	QAction* m_viewStatusBar;
+	QAction* m_settingsAutoHideTags;
 	QAction* m_settingsShowHidePicture;
 
 	static BrowserDialog* s_helpBrowser;
