@@ -118,19 +118,32 @@ MiscConfig::MiscConfig(const QString& group) :
 	m_renDirSrc(0),
 	m_numberTracksDst(0),
 	m_numberTracksStart(1),
+#ifndef CONFIG_USE_KDE
+#if QT_VERSION >= 0x040000
+	m_hideToolBar(false),
+#endif
+	m_hideStatusBar(false),
+#endif
+	m_autoHideTags(true),
+	m_hideFile(false),
 	m_hideV1(false),
 	m_hideV2(false),
 	m_hidePicture(false),
 	m_id3v2Version(ID3v2_3_0),
 	m_textEncodingV1(""),
 	m_textEncoding(TE_ISO8859_1),
+	m_trackNumberDigits(1),
 	m_useProxy(false),
 #if QT_VERSION >= 0x040000
 	m_useProxyAuthentication(false),
 #endif
 	m_onlyCustomGenres(false)
 #ifndef CONFIG_USE_KDE
+#if QT_VERSION >= 0x040200
+	,
+#else
 	, m_windowX(-1), m_windowY(-1), m_windowWidth(-1), m_windowHeight(-1),
+#endif
 	m_useFont(false), m_fontSize(-1)
 #endif
 {
@@ -178,12 +191,15 @@ void MiscConfig::writeToConfig(
 	cfg.writeEntry("SplitterSizes", m_splitterSizes);
 	cfg.writeEntry("VSplitterSizes", m_vSplitterSizes);
 	cfg.writeEntry("CustomGenres", m_customGenres);
+	cfg.writeEntry("AutoHideTags", m_autoHideTags);
+	cfg.writeEntry("HideFile", m_hideFile);
 	cfg.writeEntry("HideV1", m_hideV1);
 	cfg.writeEntry("HideV2", m_hideV2);
 	cfg.writeEntry("HidePicture", m_hidePicture);
 	cfg.writeEntry("ID3v2Version", m_id3v2Version);
 	cfg.writeEntry("TextEncodingV1", m_textEncodingV1);
 	cfg.writeEntry("TextEncoding", m_textEncoding);
+	cfg.writeEntry("TrackNumberDigits", m_trackNumberDigits);
 	cfg.writeEntry("UseProxy", m_useProxy);
 	cfg.writeEntry("Proxy", m_proxy);
 #if QT_VERSION >= 0x040000
@@ -250,12 +266,19 @@ void MiscConfig::writeToConfig(
 		config->QCM_writeEntry("/VSplitterSize" + QString::number(i), *it);
 	}
 	config->QCM_writeEntry("/CustomGenres", m_customGenres);
+#if QT_VERSION >= 0x040000
+	config->QCM_writeEntry("/HideToolBar", m_hideToolBar);
+#endif
+	config->QCM_writeEntry("/HideStatusBar", m_hideStatusBar);
+	config->QCM_writeEntry("/AutoHideTags", m_autoHideTags);
+	config->QCM_writeEntry("/HideFile", m_hideFile);
 	config->QCM_writeEntry("/HideV1", m_hideV1);
 	config->QCM_writeEntry("/HideV2", m_hideV2);
 	config->QCM_writeEntry("/HidePicture", m_hidePicture);
 	config->QCM_writeEntry("/ID3v2Version", m_id3v2Version);
 	config->QCM_writeEntry("/TextEncodingV1", m_textEncodingV1);
 	config->QCM_writeEntry("/TextEncoding", m_textEncoding);
+	config->QCM_writeEntry("/TrackNumberDigits", m_trackNumberDigits);
 	config->QCM_writeEntry("/UseProxy", m_useProxy);
 	config->QCM_writeEntry("/Proxy", m_proxy);
 #if QT_VERSION >= 0x040000
@@ -265,10 +288,15 @@ void MiscConfig::writeToConfig(
 #endif
 	config->QCM_writeEntry("/Browser", m_browser);
 	config->QCM_writeEntry("/OnlyCustomGenres", m_onlyCustomGenres);
+#if QT_VERSION >= 0x040200
+	config->setValue("/Geometry", m_geometry);
+	config->setValue("/WindowState", m_windowState);
+#else
 	config->QCM_writeEntry("/WindowX", m_windowX);
 	config->QCM_writeEntry("/WindowY", m_windowY);
 	config->QCM_writeEntry("/WindowWidth", m_windowWidth);
 	config->QCM_writeEntry("/WindowHeight", m_windowHeight);
+#endif
 	config->QCM_writeEntry("/UseFont", m_useFont);
 	config->QCM_writeEntry("/FontFamily", m_fontFamily);
 	config->QCM_writeEntry("/FontSize", m_fontSize);
@@ -343,12 +371,15 @@ void MiscConfig::readFromConfig(
 	m_splitterSizes = cfg.KCM_readIntListEntry("SplitterSizes");
 	m_vSplitterSizes = cfg.KCM_readIntListEntry("VSplitterSizes");
 	m_customGenres = cfg.KCM_readListEntry("CustomGenres");
+	m_autoHideTags = cfg.KCM_readBoolEntry("AutoHideTags", m_autoHideTags);
+	m_hideFile = cfg.KCM_readBoolEntry("HideFile", m_hideFile);
 	m_hideV1 = cfg.KCM_readBoolEntry("HideV1", m_hideV1);
 	m_hideV2 = cfg.KCM_readBoolEntry("HideV2", m_hideV2);
 	m_hidePicture = cfg.KCM_readBoolEntry("HidePicture", m_hidePicture);
 	m_id3v2Version = cfg.KCM_readNumEntry("ID3v2Version", static_cast<int>(ID3v2_3_0));
 	m_textEncodingV1 = cfg.readEntry("TextEncodingV1", "");
 	m_textEncoding = cfg.KCM_readNumEntry("TextEncoding", static_cast<int>(TE_ISO8859_1));
+	m_trackNumberDigits = cfg.KCM_readNumEntry("TrackNumberDigits", 1);
 	m_useProxy = cfg.KCM_readBoolEntry("UseProxy", m_useProxy);
 	m_proxy = cfg.readEntry("Proxy", m_proxy);
 #if QT_VERSION >= 0x040000
@@ -420,12 +451,19 @@ void MiscConfig::readFromConfig(
 		}
 	}
 	m_customGenres = config->QCM_readListEntry("/CustomGenres");
+#if QT_VERSION >= 0x040000
+	m_hideToolBar = config->QCM_readBoolEntry("/HideToolBar", m_hideToolBar);
+#endif
+	m_hideStatusBar = config->QCM_readBoolEntry("/HideStatusBar", m_hideStatusBar);
+	m_autoHideTags = config->QCM_readBoolEntry("/AutoHideTags", m_autoHideTags);
+	m_hideFile = config->QCM_readBoolEntry("/HideFile", m_hideFile);
 	m_hideV1 = config->QCM_readBoolEntry("/HideV1", m_hideV1);
 	m_hideV2 = config->QCM_readBoolEntry("/HideV2", m_hideV2);
 	m_hidePicture = config->QCM_readBoolEntry("/HidePicture", m_hidePicture);
 	m_id3v2Version = config->QCM_readNumEntry("/ID3v2Version", ID3v2_3_0);
 	m_textEncodingV1 = config->QCM_readEntry("/TextEncodingV1", "");
 	m_textEncoding = config->QCM_readNumEntry("/TextEncoding", TE_ISO8859_1);
+	m_trackNumberDigits = config->QCM_readNumEntry("/TrackNumberDigits", 1);
 	m_useProxy = config->QCM_readBoolEntry("/UseProxy", m_useProxy);
 	m_proxy = config->QCM_readEntry("/Proxy", m_proxy);
 #if QT_VERSION >= 0x040000
@@ -443,10 +481,15 @@ void MiscConfig::readFromConfig(
 	m_browser = config->QCM_readEntry("/Browser", s_defaultBrowser);
 #endif
 	m_onlyCustomGenres = config->QCM_readBoolEntry("/OnlyCustomGenres", m_onlyCustomGenres);
+#if QT_VERSION >= 0x040200
+	m_geometry = config->value("/Geometry").toByteArray();
+	m_windowState = config->value("/WindowState").toByteArray();
+#else
 	m_windowX = config->QCM_readNumEntry("/WindowX", -1);
 	m_windowY = config->QCM_readNumEntry("/WindowY", -1);
 	m_windowWidth = config->QCM_readNumEntry("/WindowWidth", -1);
 	m_windowHeight = config->QCM_readNumEntry("/WindowHeight", -1);
+#endif
 	m_useFont = config->QCM_readBoolEntry("/UseFont", m_useFont);
 	m_fontFamily = config->QCM_readEntry("/FontFamily", m_fontFamily);
 	m_fontSize = config->QCM_readNumEntry("/FontSize", -1);
@@ -479,7 +522,7 @@ void MiscConfig::readFromConfig(
 				QString('"') + prgDir +  "\\Album Cover Art Downloader\\albumart-qt.exe\" %{directory}"));
 #elif !defined __APPLE__
 		m_contextMenuCommands.push_back(
-			MiscConfig::MenuCommand("xmms", "xmms %{files}"));
+			MiscConfig::MenuCommand("Amarok", "amarok %{files}"));
 		m_contextMenuCommands.push_back(
 			MiscConfig::MenuCommand("AlbumArt", "albumart-qt %{directory}"));
 #endif
