@@ -219,6 +219,18 @@ public:
 	MenuCommandList m_contextMenuCommands;
 	/** custom genres for ID3v2.3 */
 	QStringList m_customGenres;
+#ifndef CONFIG_USE_KDE
+#if QT_VERSION >= 0x040000
+	/** true to hide toolbar */
+	bool m_hideToolBar;
+#endif
+	/** true to hide statusbar */
+	bool m_hideStatusBar;
+#endif
+	/** true to automatically hide unused tags */
+	bool m_autoHideTags;
+	/** true to hide file controls */
+	bool m_hideFile;
 	/** true to hide ID3v1.1 controls */
 	bool m_hideV1;
 	/** true to hide ID3v2.3 controls */
@@ -231,6 +243,8 @@ public:
 	QString m_textEncodingV1;
 	/** text encoding used for new ID3v2 tags */
 	int m_textEncoding;
+	/** number of digits in track number */
+	int m_trackNumberDigits;
 	/** true if proxy is used */
 	bool m_useProxy;
 	/** proxy used for access */
@@ -248,6 +262,12 @@ public:
 	/** true to show only custom genres in combo boxes */
 	bool m_onlyCustomGenres;
 #ifndef CONFIG_USE_KDE
+#if QT_VERSION >= 0x040200
+	/** mainwindow geometry */
+	QByteArray m_geometry;
+	/** mainwindow state */
+	QByteArray m_windowState;
+#else
 	/** mainwindow x-position */
 	int m_windowX;
 	/** mainwindow y-position */
@@ -256,6 +276,7 @@ public:
 	int m_windowWidth;
 	/** mainwindow height */
 	int m_windowHeight;
+#endif
 	/** true if custom application font is used */
 	bool m_useFont;
 	/** custom application font family */
