@@ -632,24 +632,15 @@ static bool setYear(ID3_Tag* tag, int num)
  *
  * @param tag ID3 tag
  * @param num number to set, 0 to remove field.
- * @param numTracks total number of tracks, -1 to ignore
+ * @param numTracks total number of tracks, <=0 to ignore
  *
  * @return true if the field was changed.
  */
-static bool setTrackNum(ID3_Tag* tag, int num, int numTracks = -1)
+bool Mp3File::setTrackNum(ID3_Tag* tag, int num, int numTracks) const
 {
 	bool changed = false;
 	if (num >= 0 && getTrackNum(tag) != num) {
-		QString str;
-		if (num != 0) {
-			str.setNum(num);
-			if (numTracks > 0) {
-				str += '/';
-				str += QString::number(numTracks);
-			}
-		} else {
-			str = "";
-		}
+		QString str = trackNumberString(num, numTracks);
 		changed = getTextField(tag, ID3FID_TRACKNUM) != str &&
 		          setTextField(tag, ID3FID_TRACKNUM, str);
 	}
@@ -834,13 +825,13 @@ int Mp3File::getYearV2()
 /**
  * Get ID3v2 track.
  *
- * @return number,
- *         0 if the field does not exist,
- *         -1 if the tags do not exist.
+ * @return string,
+ *         "" if the field does not exist,
+ *         QString::null if the tags do not exist.
  */
-int Mp3File::getTrackNumV2()
+QString Mp3File::getTrackV2()
 {
-	return getTrackNum(m_tagV2);
+	return getTextField(m_tagV2, ID3FID_TRACKNUM);
 }
 
 /**
@@ -1031,11 +1022,12 @@ void Mp3File::setYearV2(int num)
 /**
  * Set ID3v2 track.
  *
- * @param num number to set, 0 to remove field.
+ * @param track string to set, "" to remove field, QString::null to ignore.
  */
-void Mp3File::setTrackNumV2(int num)
+void Mp3File::setTrackV2(const QString& track)
 {
-	int numTracks = getTotalNumberOfTracksIfEnabled();
+	int numTracks;
+	int num = splitNumberAndTotal(track, &numTracks);
 	if (setTrackNum(m_tagV2, num, numTracks)) {
 		markTag2Changed(Frame::FT_Track);
 	}
@@ -1220,7 +1212,11 @@ unsigned Mp3File::getDuration() const
  */
 QString Mp3File::getFileExtension() const
 {
-	return ".mp3";
+	QString ext(getFilename().right(4).QCM_toLower());
+	if (ext == ".aac" || ext == ".mp2")
+		return ext;
+	else
+		return ".mp3";
 }
 
 /**
@@ -1559,7 +1555,7 @@ void Mp3File::setId3v2Frame(ID3_Frame* id3Frame, const Frame& frame) const
 						value = Genres::getNumberString(value, true);
 					}
 				} else if (id3Id == ID3FID_TRACKNUM) {
-					addTotalNumberOfTracksIfEnabled(value);
+					formatTrackNumberIfEnabled(value, true);
 				}
 				setString(id3Field, value);
 				break;
@@ -1604,14 +1600,20 @@ bool Mp3File::setFrameV2(const Frame& frame)
 			if (frame.isValueChanged() || frame.getFieldList().empty()) {
 				QString value(frame.getValue());
 				ID3_Field* fld;
-				if ((fld = id3Frame->GetField(ID3FN_TEXT)) != 0 ||
+				if ((fld = id3Frame->GetField(ID3FN_URL)) != 0) {
+					if (getString(fld) != value) {
+						fld->Set(value.QCM_latin1());
+						markTag2Changed(frame.getType());
+					}
+					return true;
+				} else if ((fld = id3Frame->GetField(ID3FN_TEXT)) != 0 ||
 						(fld = id3Frame->GetField(ID3FN_DESCRIPTION)) != 0) {
 					if (id3Frame->GetID() == ID3FID_CONTENTTYPE) {
 						if (!Kid3App::s_miscCfg.m_genreNotNumeric) {
 							value = Genres::getNumberString(value, true);
 						}
 					} else if (id3Frame->GetID() == ID3FID_TRACKNUM) {
-						addTotalNumberOfTracksIfEnabled(value);
+						formatTrackNumberIfEnabled(value, true);
 					}
 					if (fld->GetEncoding() == ID3TE_ISO8859_1) {
 						// check if information is lost if the string is not unicode
@@ -1640,12 +1642,6 @@ bool Mp3File::setFrameV2(const Frame& frame)
 						markTag2Changed(frame.getType());
 					}
 					return true;
-				} else if ((fld = id3Frame->GetField(ID3FN_URL)) != 0) {
-					if (getString(fld) != value) {
-						fld->Set(value.QCM_latin1());
-						markTag2Changed(frame.getType());
-					}
-					return true;
 				} else if (id3Frame->GetID() == ID3FID_PRIVATE &&
 					         (fld = id3Frame->GetField(ID3FN_DATA)) != 0) {
 					ID3_Field* ownerFld = id3Frame->GetField(ID3FN_OWNER);
