@@ -220,11 +220,11 @@ public:
 	/**
 	 * Get ID3v2 track.
 	 *
-	 * @return number,
-	 *         0 if the field does not exist,
-	 *         -1 if the tags do not exist.
+	 * @return string,
+	 *         "" if the field does not exist,
+	 *         QString::null if the tags do not exist.
 	 */
-	virtual int getTrackNumV2();
+	virtual QString getTrackV2();
 
 	/**
 	 * Get ID3v2 genre as text.
@@ -322,9 +322,9 @@ public:
 	/**
 	 * Set ID3v2 track.
 	 *
-	 * @param num number to set, 0 to remove field.
+	 * @param track string to set, "" to remove field, QString::null to ignore.
 	 */
-	virtual void setTrackNumV2(int num);
+	virtual void setTrackV2(const QString& track);
 
 	/**
 	 * Set ID3v2 genre as text.
@@ -465,6 +465,17 @@ public:
 	static ID3_TextEnc getDefaultTextEncoding() { return s_defaultTextEncoding; }
 
 private:
+	/**
+	 * Set track.
+	 *
+	 * @param tag ID3 tag
+	 * @param num number to set, 0 to remove field.
+	 * @param numTracks total number of tracks, <=0 to ignore
+	 *
+	 * @return true if the field was changed.
+	 */
+	bool setTrackNum(ID3_Tag* tag, int num, int numTracks = 0) const;
+
 	/**
 	 * Set the fields in an id3lib frame from the field in the frame.
 	 *
