@@ -46,6 +46,7 @@
 #define KCM_ICON_preferences_files "document-save"
 #define KCM_ICON_preferences_useractions "preferences-other"
 #define KCM_ICON_preferences_network "preferences-system-network"
+#define KCM_ICON_media_playback_start "media-playback-start"
 
 #define KCM_setStatusTip setStatusTip
 #define KCM_addUrl addUrl
@@ -72,6 +73,11 @@
 	KAction* var = new KAction(text, this); \
 	parent->addAction(name, var); \
 	connect(var, SIGNAL(triggered()), rcvr, slot)
+#define KCM_KToggleActionVar(var, text, rcvr, slot, parent, name)	\
+	var = new KToggleAction(text, this); \
+	var->setCheckable(true); \
+	parent->addAction(name, var); \
+	connect(var, SIGNAL(triggered()), rcvr, slot)
 #define KCM_KConfigGroup(var, cfgptr, name) KConfigGroup var = cfgptr->group(name)
 #define KCM_readBoolEntry readEntry
 #define KCM_readNumEntry readEntry
@@ -93,6 +99,7 @@
 #define KCM_ICON_preferences_files "package_system"
 #define KCM_ICON_preferences_useractions "package_utilities"
 #define KCM_ICON_preferences_network "package_network"
+#define KCM_ICON_media_playback_start "player_play"
 
 #define KCM_setStatusTip setStatusText
 #define KCM_addUrl addURL
@@ -109,6 +116,8 @@
 	var = new KAction(text, 0, rcvr, slot, parent, name)
 #define KCM_KAction(var, text, rcvr, slot, parent, name)	\
 	new KAction(text, 0, rcvr, slot, parent, name)
+#define KCM_KToggleActionVar(var, text, rcvr, slot, parent, name)	\
+	var = new KToggleAction(text, 0, rcvr, slot, parent, name)
 #define KCM_KConfigGroup(var, cfgptr, name) KConfig& var = *cfgptr; cfgptr->setGroup(name)
 #define KCM_readBoolEntry readBoolEntry
 #define KCM_readNumEntry readNumEntry
@@ -203,6 +212,7 @@
 #define QCM_readAll readAll
 #define QCM_setIcon setIcon
 #define QCM_QCString QByteArray
+#define QCM_setIconSet setIcon
 
 #else
 
@@ -277,6 +287,7 @@ namespace QAbstractSocket { enum SocketError {}; }
 #define QCM_readAll read
 #define QCM_setIcon setPixmap
 #define QCM_QCString QCString
+#define QCM_setIconSet setIconSet
 
 #endif
 
