@@ -413,7 +413,8 @@ void TaggedFile::getTagsFromFilename(FrameCollection& frames, const QString& fmt
 					// remove leading zero
 					str = str.mid(1);
 				}
-				frames.setValue(Frame::getTypeFromName(name), str);
+				if (name != "ignore")
+					frames.setValue(Frame::getTypeFromName(name), str);
 			}
 		}
 		return;
@@ -606,6 +607,30 @@ QString TaggedFile::getCommentFieldName() const
 	return Kid3App::s_miscCfg.m_commentName;
 }
 
+/**
+ * Split a track string into number and total.
+ *
+ * @param str track
+ * @param total the total is returned here if found, else 0
+ *
+ * @return number, 0 if parsing failed, -1 if str is null
+ */
+int TaggedFile::splitNumberAndTotal(const QString& str, int* total)
+{
+	if (*total)
+		*total = 0;
+	if (str.isNull())
+		return -1;
+
+	int slashPos = str.QCM_indexOf('/');
+	if (slashPos == -1)
+		return str.toInt();
+
+	if (total)
+		*total = str.mid(slashPos + 1).toInt();
+	return str.left(slashPos).toInt();
+}
+
 /**
  * Get the total number of tracks if it is enabled.
  *
@@ -622,24 +647,76 @@ int TaggedFile::getTotalNumberOfTracksIfEnabled() const
 }
 
 /**
- * Add the total number of tracks to the track number if enabled.
+ * Format track number/total number of tracks with configured digits.
  *
- * @param value string containing track number,
- *              "/t" with t = total number of tracks will be appended
- *              if enabled and value contains a number
+ * @param num track number, <= 0 if empty
+ * @param numTracks total number of tracks, <= 0 to disable
+ *
+ * @return formatted "track/total" string.
  */
-void TaggedFile::addTotalNumberOfTracksIfEnabled(QString& value) const
+QString TaggedFile::trackNumberString(int num, int numTracks) const
 {
-	int numTracks = getTotalNumberOfTracksIfEnabled();
-	if (numTracks > 0) {
+	int numDigits = getTrackNumberDigits();
+	QString str;
+	if (num != 0) {
+		if (numDigits > 0) {
+			str.sprintf("%0*d", numDigits, num);
+		} else {
+			str.setNum(num);
+		}
+		if (numTracks > 0) {
+			str += '/';
+			if (numDigits > 0) {
+				str += QString().sprintf("%0*d", numDigits, numTracks);
+			} else {
+				str += QString::number(numTracks);
+			}
+		}
+	} else {
+		str = "";
+	}
+	return str;
+}
+
+/**
+ * Format the track number (digits, total number of tracks) if enabled.
+ *
+ * @param value    string containing track number, will be modified
+ * @param addTotal true to add total number of tracks if enabled
+ *                 "/t" with t = total number of tracks will be appended
+ *                 if enabled and value contains a number
+ */
+void TaggedFile::formatTrackNumberIfEnabled(QString& value, bool addTotal) const
+{
+	int numDigits = getTrackNumberDigits();
+	int numTracks = addTotal ? getTotalNumberOfTracksIfEnabled() : -1;
+	if (numTracks > 0 || numDigits > 1) {
 		bool ok;
 		int trackNr = value.toInt(&ok);
 		if (ok && trackNr > 0) {
-			value = QString("%1/%2").arg(trackNr).arg(numTracks);
+			if (numTracks > 0) {
+				value.sprintf("%0*d/%0*d", numDigits, trackNr, numDigits, numTracks);
+			} else {
+				value.sprintf("%0*d", numDigits, trackNr);
+			}
 		}
 	}
 }
 
+/**
+ * Get the number of track number digits configured.
+ *
+ * @return track number digits,
+ *         1 if invalid or unavailable.
+ */
+int TaggedFile::getTrackNumberDigits() const
+{
+	int numDigits = Kid3App::s_miscCfg.m_trackNumberDigits;
+	if (numDigits < 1 || numDigits > 5)
+		numDigits = 1;
+	return numDigits;
+}
+
 /**
  * Remove ID3v2 frames.
  *
@@ -652,7 +729,7 @@ void TaggedFile::deleteFramesV2(const FrameFilter& flt)
 	if (flt.isEnabled(Frame::FT_Album))   setAlbumV2("");
 	if (flt.isEnabled(Frame::FT_Comment)) setCommentV2("");
 	if (flt.isEnabled(Frame::FT_Date))    setYearV2(0);
-	if (flt.isEnabled(Frame::FT_Track))   setTrackNumV2(0);
+	if (flt.isEnabled(Frame::FT_Track))   setTrackV2("");
 	if (flt.isEnabled(Frame::FT_Genre))   setGenreV2("");
 }
 
@@ -861,8 +938,7 @@ bool TaggedFile::getFrameV2(Frame::Type type, Frame& frame)
 			frame.m_value = getTitleV2();
 			break;
 		case Frame::FT_Track:
-			n = getTrackNumV2();
-			number = true;
+			frame.m_value = getTrackV2();
 			break;
 		default:
 			// maybe handled in a subclass
@@ -891,8 +967,7 @@ bool TaggedFile::getFrameV2(Frame::Type type, Frame& frame)
 bool TaggedFile::setFrameV2(const Frame& frame)
 {
 	int n = -1;
-	if (frame.m_type == Frame::FT_Date ||
-			frame.m_type == Frame::FT_Track) {
+	if (frame.m_type == Frame::FT_Date) {
 		if (frame.isInactive()) {
 			n = -1;
 		} else if (frame.isEmpty()) {
@@ -921,7 +996,7 @@ bool TaggedFile::setFrameV2(const Frame& frame)
 			setTitleV2(frame.m_value);
 			break;
 		case Frame::FT_Track:
-			setTrackNumV2(n);
+			setTrackV2(frame.m_value);
 			break;
 		default:
 			// maybe handled in a subclass
